==> haskell-zinza-0.2-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-9UsDi6MRang2VoYKVb2Vt5
key:                  zinza-0.2-9UsDi6MRang2VoYKVb2Vt5
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  2b41f45a46d4846516d89c58cc376a19
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/zinza-0.2
hs-libraries:         HSzinza-0.2-9UsDi6MRang2VoYKVb2Vt5
depends:
    base-4.15.1.0 containers-0.6.4.1 parsec-3.1.14.0 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zinza-0.2-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-39AASkcr86W1RHvnFliVy2
key:                  zinza-0.2-39AASkcr86W1RHvnFliVy2
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  8ff1510fac7b70cf06c92945d273fbf7
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/zinza-0.2
hs-libraries:         HSzinza-0.2-39AASkcr86W1RHvnFliVy2
depends:
    base-4.15.1.0 containers-0.6.4.1 parsec-3.1.14.0 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
